@@ -1,7 +1,15 @@
 import os
 import pathlib
 from gsc import cli
-from gsc.exercises import sync_error, merge_conflict, multiple_remotes, use_the_force
+from gsc.exercises import (
+    sync_error,
+    merge_conflict,
+    multiple_remotes,
+    use_the_force,
+    revert,
+    reset_file,
+    amend,
+)
 
 
 class ResetError(Exception):
@@ -28,5 +36,11 @@ def reset():
         multiple_remotes.reset()
     if gsc_id == "use_the_force":
         use_the_force.reset()
+    if gsc_id == "revert":
+        revert.reset()
+    if gsc_id == "reset_file":
+        reset_file.reset()
+    if gsc_id == "amend":
+        amend.reset()
     else:
         raise ResetError("Unknown Git Scientist exercise. Try upgrading gsc.")
